@@ -35,7 +35,7 @@ from .workflows import Workflow
 from .workflows import WorkflowManager
 
 __name__ = "thoth-common"
-__version__ = "0.13.8"
+__version__ = "0.13.10"
 
 
 __all__ = [
@@ -52,7 +52,7 @@ __all__ = [
     "RuntimeEnvironment",
     "SafeJSONEncoder",
     "ThothAdviserIntegrationEnum",
-    "Workflow"
-    "WorkflowManager"
+    "Workflow",
+    "WorkflowManager",
     "timestamp2datetime",
 ]
